==> ocre_v0_031.tgz: ocre-0.031/ocre/src/vteclado.c <==

#include <stdlib.h>
#include <gtk/gtk.h>

#include "idiom.h"
#include "interface.h"
#include "opcns.h"

static char * tecladoRus [] = {
  // ruso  67
  "\xc9\xaa",
  "\xd0\x90", "\xd0\x91", "\xd0\x92", "\xd0\x93", "\xd0\x94", "\xd0\x95",
  "\xd0\x96", "\xd0\x97", "\xd0\x98", "\xd0\x99", "\xd0\x9a", "\xd0\x9b",
  "\xd0\x9c", "\xd0\x9d", "\xd0\x9e", "\xd0\x9f",
  "\xd0\xa0", "\xd0\xa1", "\xd0\xa2", "\xd0\xa3", "\xd0\xa4", "\xd0\xa5",
  "\xd0\xa6", "\xd0\xa7", "\xd0\xa8", "\xd0\xa9", "\xd0\xaa", "\xd0\xab",
  "\xd0\xac", "\xd0\xad", "\xd0\xae", "\xd0\xaf",
  "\xd0\x81",
  "\xd0\xb0", "\xd0\xb1", "\xd0\xb2", "\xd0\xb3", "\xd0\xb4", "\xd0\xb5",
  "\xd0\xb6", "\xd0\xb7", "\xd0\xb8", "\xd0\xb9", "\xd0\xba", "\xd0\xbb",
  "\xd0\xbc", "\xd0\xbd", "\xd0\xbe", "\xd0\xbf",
  "\xd1\x80", "\xd1\x81", "\xd1\x82", "\xd1\x83", "\xd1\x84", "\xd1\x85",
  "\xd1\x86", "\xd1\x87", "\xd1\x88", "\xd1\x89", "\xd1\x8a", "\xd1\x8b",
  "\xd1\x8c", "\xd1\x8d", "\xd1\x8e", "\xd1\x8f",
  "\xd1\x91"
} ;
static char * tecladoEspa [] = {
  // espanyol  2
  "\xc2\xaa", "\xc2\xba"
} ;
static char * tecladoHebr [] = {
  // hebreo  5 
  "\xd7\x91", "\xd7\x92", "\xd7\x93", "\xd7\x94", "\xd7\x91\xd7\x92"
} ;
static char * tecladoPort [] = {
  // portugues  22
  "\xc3\x80", "\xc3\x81", "\xc3\x83", "\xc3\x87", "\xc3\x89", "\xc3\x8a",
  "\xc3\x8d", "\xc3\x93", "\xc3\x94", "\xc3\x95", "\xc3\x9a", "\xc3\xa0",
  "\xc3\xa1", "\xc3\xa3", "\xc3\xa7", "\xc3\xa9", "\xc3\xaa", "\xc3\xad",
  "\xc3\xb3", "\xc3\xb4", "\xc3\xb5", "\xc3\xba"
} ;
static char * tecladoPol [] = {
  // polaco  18 
  "\xc4\x84", "\xc4\x85", "\xc4\x86", "\xc4\x87", "\xc4\x98", "\xc4\x99",
  "\xc5\x81", "\xc5\x82", "\xc5\x83", "\xc5\x84", "\xc3\x93", "\xc3\xb3",
  "\xc5\x9a", "\xc5\x9b", "\xc5\xb9", "\xc5\xba", "\xc5\xbb", "\xc5\xbc"
} ;
static char * tecladoIta [] = {
  // italiano  20 
  "\xc3\x80", "\xc3\x88", "\xc3\x89", "\xc3\x8c", "\xc3\x8d", "\xc3\x8e",
  "\xc3\x92", "\xc3\x93", "\xc3\x99", "\xc3\x9a", "\xc3\xa0", "\xc3\xa8",
  "\xc3\xa9", "\xc3\xac", "\xc3\xad", "\xc3\xae", "\xc3\xb2", "\xc3\xb3",
  "\xc3\xb9", "\xc3\xba"
} ;
static char * tecladoAlem [] = {
  // aleman  7 
  "\xc3\x84", "\xc3\x96", "\xc3\x9c", "\xc3\x9f", "\xc3\xa4", "\xc3\xb6",
  "\xc3\xbc"
} ;
static char * tecladoEspe [] = {
  // esperanto  12 
  "\xc4\x88", "\xc4\x9c", "\xc4\xa4", "\xc4\xb4", "\xc5\x9c", "\xc5\xac",
  "\xc4\x89", "\xc4\x9d", "\xc4\xa5", "\xc4\xb5", "\xc5\x9d", "\xc5\xad"
} ;
static char * tecladoIsl [] = {
  // islandes  16 
  "\xc3\x86", "\xc3\x89", "\xc3\x8d", "\xc3\x90", "\xc3\x93", "\xc3\x96",
  "\xc3\x9a", "\xc3\x9e", "\xc3\xa6", "\xc3\xa9", "\xc3\xad", "\xc3\xb0",
  "\xc3\xb3", "\xc3\xb6", "\xc3\xba", "\xc3\xbe"
} ;
static char * tecladoFra [] = {
  // frances  26 
  "\xc3\x80", "\xc3\x82", "\xc3\x86", "\xc3\x87", "\xc3\x88", "\xc3\x8a",
  "\xc3\x8b", "\xc3\x8e", "\xc3\x8f", "\xc3\x94", "\xc3\x9b", "\xc3\xa0",
  "\xc3\xa2", "\xc3\xa6", "\xc3\xa7", "\xc3\xa8", "\xc3\xaa", "\xc3\xab",
  "\xc3\xae", "\xc3\xaf", "\xc3\xb4", "\xc3\xbb", "\xc3\xbf", "\xc5\x92",
  "\xc5\x93", "\xc5\xb8"
} ;
static char * tecladoPnt [] = {
  // puntuacion  11 
  "\xc2\xab", "\xc2\xbb",
  "\xe2\x80\x93", "\xe2\x80\x95", "\xe2\x80\x98", "\xe2\x80\x99", "\xe2\x80\x9b",
  "\xe2\x80\x9c", "\xe2\x80\x9d", "\xe2\x80\x9e", "\xe2\x80\x9f"
} ;
static char * tecladoViet [] = {
  // vietnamita  134 
"\xc3\x80", "\xc3\x81", "\xc3\x82", "\xc3\x83", "\xc3\x88",
"\xc3\x89", "\xc3\x8a", "\xc3\x8c", "\xc3\x8d", "\xc3\x92",
"\xc3\x93", "\xc3\x94", "\xc3\x95", "\xc3\x99", "\xc3\x9a",
"\xc3\x9d", "\xc3\xa0", "\xc3\xa1", "\xc3\xa2", "\xc3\xa3",
"\xc3\xa8", "\xc3\xa9", "\xc3\xaa", "\xc3\xac", "\xc3\xad",
"\xc3\xb2", "\xc3\xb3", "\xc3\xb4", "\xc3\xb5", "\xc3\xb9",
"\xc3\xba", "\xc3\xbd", "\xc4\x82", "\xc4\x83", "\xc4\x90",
"\xc4\x91", "\xc4\xa8", "\xc4\xa9", "\xc5\xa8", "\xc5\xa9",
"\xc6\xa0", "\xc6\xa1", "\xc6\xaf", "\xc6\xb0",
"\xe1\xba\xa0", "\xe1\xba\xa1", "\xe1\xba\xa2", "\xe1\xba\xa3",
"\xe1\xba\xa4", "\xe1\xba\xa5", "\xe1\xba\xa6", "\xe1\xba\xa7",
"\xe1\xba\xa8", "\xe1\xba\xa9", "\xe1\xba\xaa", "\xe1\xba\xab",
"\xe1\xba\xac", "\xe1\xba\xad", "\xe1\xba\xae", "\xe1\xba\xaf",
"\xe1\xba\xb0", "\xe1\xba\xb1", "\xe1\xba\xb2", "\xe1\xba\xb3",
"\xe1\xba\xb4", "\xe1\xba\xb5", "\xe1\xba\xb6", "\xe1\xba\xb7",
"\xe1\xba\xb8", "\xe1\xba\xb9", "\xe1\xba\xba", "\xe1\xba\xbb",
"\xe1\xba\xbc", "\xe1\xba\xbd", "\xe1\xba\xbe", "\xe1\xba\xbf",
"\xe1\xbb\x80", "\xe1\xbb\x81", "\xe1\xbb\x82", "\xe1\xbb\x83",
"\xe1\xbb\x84", "\xe1\xbb\x85", "\xe1\xbb\x86", "\xe1\xbb\x87",
"\xe1\xbb\x88", "\xe1\xbb\x89", "\xe1\xbb\x8a", "\xe1\xbb\x8b",
"\xe1\xbb\x8c", "\xe1\xbb\x8d", "\xe1\xbb\x8e", "\xe1\xbb\x8f",
"\xe1\xbb\x90", "\xe1\xbb\x91", "\xe1\xbb\x92", "\xe1\xbb\x93",
"\xe1\xbb\x94", "\xe1\xbb\x95", "\xe1\xbb\x96", "\xe1\xbb\x97",
"\xe1\xbb\x98", "\xe1\xbb\x99", "\xe1\xbb\x9a", "\xe1\xbb\x9b",
"\xe1\xbb\x9c", "\xe1\xbb\x9d", "\xe1\xbb\x9e", "\xe1\xbb\x9f",
"\xe1\xbb\xa0", "\xe1\xbb\xa1", "\xe1\xbb\xa2", "\xe1\xbb\xa3",
"\xe1\xbb\xa4", "\xe1\xbb\xa5", "\xe1\xbb\xa6", "\xe1\xbb\xa7",
"\xe1\xbb\xa8", "\xe1\xbb\xa9", "\xe1\xbb\xaa", "\xe1\xbb\xab",
"\xe1\xbb\xac", "\xe1\xbb\xad", "\xe1\xbb\xae", "\xe1\xbb\xaf",
"\xe1\xbb\xb0", "\xe1\xbb\xb1", "\xe1\xbb\xb2", "\xe1\xbb\xb3",
"\xe1\xbb\xb4", "\xe1\xbb\xb5", "\xe1\xbb\xb6", "\xe1\xbb\xb7",
"\xe1\xbb\xb8", "\xe1\xbb\xb9"
} ;
static char * tecladoMisc [] = {
  // miscelanea  4 
  "\xc2\xa2", "\xc2\xa3",
  "\xe2\x82\xac",
  "\xe2\x98\x85"
} ;

   GtkWidget *windowKb;
   GtkWidget *table;
   GtkWidget **boton;

void preparaYpresentaVen2 (char ** teclado, int nc, char * titvent)
{
   gchar **texto;
   PangoAttrList **attr;
   int ncol ;
   int nfil ;
   int i;
   texto = (gchar **)         malloc (nc * sizeof (gchar *));
   attr  = (PangoAttrList **) malloc (nc * sizeof (PangoAttrList *));
   boton = (GtkWidget **)     malloc (nc * sizeof (GtkWidget *));
   ncol = 11;
   nfil = (nc -1)/ncol + 1;
   /* ventana teclado */
   windowKb = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title(GTK_WINDOW (windowKb), titvent);
   gtk_container_set_border_width (GTK_CONTAINER (windowKb), 4);
   /* tabla */
   table = gtk_table_new (nfil, ncol, TRUE);
   gtk_widget_set_usize( GTK_WIDGET (table), ncol*30, nfil*30);
   gtk_container_add (GTK_CONTAINER (windowKb), table);
   /* cada boton con su etiqueta */
   for (i=0; i<nc; i++) {
     int f, c;
     GError         *error = NULL;
     f = i % nfil;  c = i / nfil;
     c = i % ncol;  f = i / ncol;
     if ( ! pango_parse_markup (teclado[i], -1,0,
			        &attr[i], & texto[i], NULL, &error) ) {
         g_warning ("Failed to set text from markup due to error parsing markup: %s\nThis is the text that caused the error: %s i=%3d",  error->message, teclado[i], i);
       }
     boton[i] = gtk_button_new_with_label (texto[i]);
     gtk_table_attach_defaults (GTK_TABLE(table), boton[i], c, c+1, f, f+1);
     gtk_widget_show (boton[i]);
     }
   /* cada boton con su senyal */
   for (i=0; i<nc; i++) {
     gtk_signal_connect (GTK_OBJECT (boton[i]), "clicked",
		         GTK_SIGNAL_FUNC (callbackBVteclado), teclado[i]);
     }
   /* mostrar */
   gtk_widget_show (table);
   gtk_widget_show (windowKb);
}

void preparaYpresentaVent1 ()
{
/*
  preparaYpresentaVen2 (tecladoMisc,  4, "miscel");
  preparaYpresentaVen2 (tecladoPnt , 11, "puntuacion");

*/
/*
*/
  if (l_opcion) {
    switch (l_valor_idiom) {
      case idiom_To1:
        preparaYpresentaVen2 (tecladoFra , 26, "frances");
        preparaYpresentaVen2 (tecladoAlem,  7, "aleman");
        preparaYpresentaVen2 (tecladoIsl,  16, "islandes");
        preparaYpresentaVen2 (tecladoIta,  20, "italiano");
        preparaYpresentaVen2 (tecladoPol , 18, "polaco");
        preparaYpresentaVen2 (tecladoPort,  22, "portugues");
	break ;
      case idiom_epo:
        preparaYpresentaVen2 (tecladoEspe,  12, "esperanto");
	break ;
      case idiom_fra:
        preparaYpresentaVen2 (tecladoFra , 26, "frances");
	break ;
      case idiom_ger:
        preparaYpresentaVen2 (tecladoAlem,  7, "aleman");
	break ;
      case idiom_heb:
        preparaYpresentaVen2 (tecladoHebr,  5, "hebreo");
	break ;
      case idiom_isl:
        preparaYpresentaVen2 (tecladoIsl,  16, "islandes");
	break ;
      case idiom_ita:
        preparaYpresentaVen2 (tecladoIta,  20, "italiano");
	break ;
      case idiom_pol:
        preparaYpresentaVen2 (tecladoPol , 18, "polaco");
	break ;
      case idiom_por:
        preparaYpresentaVen2 (tecladoPort,  22, "portugues");
	break ;
      case idiom_rus:
        preparaYpresentaVen2 (tecladoRus,  67, "ruso");
	break ;
      case idiom_vie:
        preparaYpresentaVen2 (tecladoViet,  134, "vietnamita");
	break ;
      }
    }
  preparaYpresentaVen2 (tecladoEspa,  2, "espanol");
  preparaYpresentaVen2 (tecladoMisc,  4, "miscel");
  preparaYpresentaVen2 (tecladoPnt , 11, "puntuacion");
}

==> ocre_v0_042.tgz: ocre-0.042/ocre/src/vteclado.c <==

#include <stdlib.h>
#include <gtk/gtk.h>

#include "idiom.h"
#include "interface.h"
#include "opcns.h"

static char * tecladoRus [] = {
  // ruso  67
  "\xc9\xaa",
  "\xd0\x90", "\xd0\x91", "\xd0\x92", "\xd0\x93", "\xd0\x94", "\xd0\x95",
  "\xd0\x96", "\xd0\x97", "\xd0\x98", "\xd0\x99", "\xd0\x9a", "\xd0\x9b",
  "\xd0\x9c", "\xd0\x9d", "\xd0\x9e", "\xd0\x9f",
  "\xd0\xa0", "\xd0\xa1", "\xd0\xa2", "\xd0\xa3", "\xd0\xa4", "\xd0\xa5",
  "\xd0\xa6", "\xd0\xa7", "\xd0\xa8", "\xd0\xa9", "\xd0\xaa", "\xd0\xab",
  "\xd0\xac", "\xd0\xad", "\xd0\xae", "\xd0\xaf",
  "\xd0\x81",
  "\xd0\xb0", "\xd0\xb1", "\xd0\xb2", "\xd0\xb3", "\xd0\xb4", "\xd0\xb5",
  "\xd0\xb6", "\xd0\xb7", "\xd0\xb8", "\xd0\xb9", "\xd0\xba", "\xd0\xbb",
  "\xd0\xbc", "\xd0\xbd", "\xd0\xbe", "\xd0\xbf",
  "\xd1\x80", "\xd1\x81", "\xd1\x82", "\xd1\x83", "\xd1\x84", "\xd1\x85",
  "\xd1\x86", "\xd1\x87", "\xd1\x88", "\xd1\x89", "\xd1\x8a", "\xd1\x8b",
  "\xd1\x8c", "\xd1\x8d", "\xd1\x8e", "\xd1\x8f",
  "\xd1\x91"
} ;
static char * tecladoEspa [] = {
  // espanyol  2
  "\xc2\xaa", "\xc2\xba"
} ;
static char * tecladoHebr [] = {
  // hebreo  5 
  "\xd7\x91", "\xd7\x92", "\xd7\x93", "\xd7\x94", "\xd7\x91\xd7\x92"
} ;
static char * tecladoPort [] = {
  // portugues  22
  "\xc3\x80", "\xc3\x81", "\xc3\x83", "\xc3\x87", "\xc3\x89", "\xc3\x8a",
  "\xc3\x8d", "\xc3\x93", "\xc3\x94", "\xc3\x95", "\xc3\x9a", "\xc3\xa0",
  "\xc3\xa1", "\xc3\xa3", "\xc3\xa7", "\xc3\xa9", "\xc3\xaa", "\xc3\xad",
  "\xc3\xb3", "\xc3\xb4", "\xc3\xb5", "\xc3\xba"
} ;
static char * tecladoPol [] = {
  // polaco  18 
  "\xc4\x84", "\xc4\x85", "\xc4\x86", "\xc4\x87", "\xc4\x98", "\xc4\x99",
  "\xc5\x81", "\xc5\x82", "\xc5\x83", "\xc5\x84", "\xc3\x93", "\xc3\xb3",
  "\xc5\x9a", "\xc5\x9b", "\xc5\xb9", "\xc5\xba", "\xc5\xbb", "\xc5\xbc"
} ;
static char * tecladoIta [] = {
  // italiano  20 
  "\xc3\x80", "\xc3\x88", "\xc3\x89", "\xc3\x8c", "\xc3\x8d", "\xc3\x8e",
  "\xc3\x92", "\xc3\x93", "\xc3\x99", "\xc3\x9a", "\xc3\xa0", "\xc3\xa8",
  "\xc3\xa9", "\xc3\xac", "\xc3\xad", "\xc3\xae", "\xc3\xb2", "\xc3\xb3",
  "\xc3\xb9", "\xc3\xba"
} ;
static char * tecladoAlem [] = {
  // aleman  7 
  "\xc3\x84", "\xc3\x96", "\xc3\x9c", "\xc3\x9f", "\xc3\xa4", "\xc3\xb6",
  "\xc3\xbc"
} ;
static char * tecladoEspe [] = {
  // esperanto  12 
  "\xc4\x88", "\xc4\x9c", "\xc4\xa4", "\xc4\xb4", "\xc5\x9c", "\xc5\xac",
  "\xc4\x89", "\xc4\x9d", "\xc4\xa5", "\xc4\xb5", "\xc5\x9d", "\xc5\xad"
} ;
static char * tecladoIsl [] = {
  // islandes  16 
  "\xc3\x86", "\xc3\x89", "\xc3\x8d", "\xc3\x90", "\xc3\x93", "\xc3\x96",
  "\xc3\x9a", "\xc3\x9e", "\xc3\xa6", "\xc3\xa9", "\xc3\xad", "\xc3\xb0",
  "\xc3\xb3", "\xc3\xb6", "\xc3\xba", "\xc3\xbe"
} ;
static char * tecladoFra [] = {
  // frances  26 
  "\xc3\x80", "\xc3\x82", "\xc3\x86", "\xc3\x87", "\xc3\x88", "\xc3\x8a",
  "\xc3\x8b", "\xc3\x8e", "\xc3\x8f", "\xc3\x94", "\xc3\x9b", "\xc3\xa0",
  "\xc3\xa2", "\xc3\xa6", "\xc3\xa7", "\xc3\xa8", "\xc3\xaa", "\xc3\xab",
  "\xc3\xae", "\xc3\xaf", "\xc3\xb4", "\xc3\xbb", "\xc3\xbf", "\xc5\x92",
  "\xc5\x93", "\xc5\xb8"
} ;
static char * tecladoPnt [] = {
  // puntuacion  12 
  "\xc2\xab", "\xc2\xbb", "\xcc\x86",
  "\xe2\x80\x93", "\xe2\x80\x95", "\xe2\x80\x98", "\xe2\x80\x99", "\xe2\x80\x9b",
  "\xe2\x80\x9c", "\xe2\x80\x9d", "\xe2\x80\x9e", "\xe2\x80\x9f"
} ;
static char * tecladoViet [] = {
  // vietnamita  134 
"\xc3\x80", "\xc3\x81", "\xc3\x82", "\xc3\x83", "\xc3\x88",
"\xc3\x89", "\xc3\x8a", "\xc3\x8c", "\xc3\x8d", "\xc3\x92",
"\xc3\x93", "\xc3\x94", "\xc3\x95", "\xc3\x99", "\xc3\x9a",
"\xc3\x9d", "\xc3\xa0", "\xc3\xa1", "\xc3\xa2", "\xc3\xa3",
"\xc3\xa8", "\xc3\xa9", "\xc3\xaa", "\xc3\xac", "\xc3\xad",
"\xc3\xb2", "\xc3\xb3", "\xc3\xb4", "\xc3\xb5", "\xc3\xb9",
"\xc3\xba", "\xc3\xbd", "\xc4\x82", "\xc4\x83", "\xc4\x90",
"\xc4\x91", "\xc4\xa8", "\xc4\xa9", "\xc5\xa8", "\xc5\xa9",
"\xc6\xa0", "\xc6\xa1", "\xc6\xaf", "\xc6\xb0",
"\xe1\xba\xa0", "\xe1\xba\xa1", "\xe1\xba\xa2", "\xe1\xba\xa3",
"\xe1\xba\xa4", "\xe1\xba\xa5", "\xe1\xba\xa6", "\xe1\xba\xa7",
"\xe1\xba\xa8", "\xe1\xba\xa9", "\xe1\xba\xaa", "\xe1\xba\xab",
"\xe1\xba\xac", "\xe1\xba\xad", "\xe1\xba\xae", "\xe1\xba\xaf",
"\xe1\xba\xb0", "\xe1\xba\xb1", "\xe1\xba\xb2", "\xe1\xba\xb3",
"\xe1\xba\xb4", "\xe1\xba\xb5", "\xe1\xba\xb6", "\xe1\xba\xb7",
"\xe1\xba\xb8", "\xe1\xba\xb9", "\xe1\xba\xba", "\xe1\xba\xbb",
"\xe1\xba\xbc", "\xe1\xba\xbd", "\xe1\xba\xbe", "\xe1\xba\xbf",
"\xe1\xbb\x80", "\xe1\xbb\x81", "\xe1\xbb\x82", "\xe1\xbb\x83",
"\xe1\xbb\x84", "\xe1\xbb\x85", "\xe1\xbb\x86", "\xe1\xbb\x87",
"\xe1\xbb\x88", "\xe1\xbb\x89", "\xe1\xbb\x8a", "\xe1\xbb\x8b",
"\xe1\xbb\x8c", "\xe1\xbb\x8d", "\xe1\xbb\x8e", "\xe1\xbb\x8f",
"\xe1\xbb\x90", "\xe1\xbb\x91", "\xe1\xbb\x92", "\xe1\xbb\x93",
"\xe1\xbb\x94", "\xe1\xbb\x95", "\xe1\xbb\x96", "\xe1\xbb\x97",
"\xe1\xbb\x98", "\xe1\xbb\x99", "\xe1\xbb\x9a", "\xe1\xbb\x9b",
"\xe1\xbb\x9c", "\xe1\xbb\x9d", "\xe1\xbb\x9e", "\xe1\xbb\x9f",
"\xe1\xbb\xa0", "\xe1\xbb\xa1", "\xe1\xbb\xa2", "\xe1\xbb\xa3",
"\xe1\xbb\xa4", "\xe1\xbb\xa5", "\xe1\xbb\xa6", "\xe1\xbb\xa7",
"\xe1\xbb\xa8", "\xe1\xbb\xa9", "\xe1\xbb\xaa", "\xe1\xbb\xab",
"\xe1\xbb\xac", "\xe1\xbb\xad", "\xe1\xbb\xae", "\xe1\xbb\xaf",
"\xe1\xbb\xb0", "\xe1\xbb\xb1", "\xe1\xbb\xb2", "\xe1\xbb\xb3",
"\xe1\xbb\xb4", "\xe1\xbb\xb5", "\xe1\xbb\xb6", "\xe1\xbb\xb7",
"\xe1\xbb\xb8", "\xe1\xbb\xb9"
} ;
static char * tecladoMisc [] = {
  // miscelanea  4 
  "\xc2\xa2", "\xc2\xa3",
  "\xe2\x82\xac",
  "\xe2\x98\x85"
} ;

   GtkWidget *windowKb;
   GtkWidget *table;
   GtkWidget **boton;

void preparaYpresentaVen2 (char ** teclado, int nc, char * titvent)
{
   gchar **texto;
   PangoAttrList **attr;
   int ncol ;
   int nfil ;
   int i;
   texto = (gchar **)         malloc (nc * sizeof (gchar *));
   attr  = (PangoAttrList **) malloc (nc * sizeof (PangoAttrList *));
   boton = (GtkWidget **)     malloc (nc * sizeof (GtkWidget *));
   ncol = 11;
   nfil = (nc -1)/ncol + 1;
   /* ventana teclado */
   windowKb = gtk_window_new (GTK_WINDOW_TOPLEVEL);
   gtk_window_set_title(GTK_WINDOW (windowKb), titvent);
   gtk_container_set_border_width (GTK_CONTAINER (windowKb), 4);
   /* tabla */
   table = gtk_table_new (nfil, ncol, TRUE);
   gtk_widget_set_usize( GTK_WIDGET (table), ncol*30, nfil*30);
   gtk_container_add (GTK_CONTAINER (windowKb), table);
   /* cada boton con su etiqueta */
   for (i=0; i<nc; i++) {
     int f, c;
     GError         *error = NULL;
     f = i % nfil;  c = i / nfil;
     c = i % ncol;  f = i / ncol;
     if ( ! pango_parse_markup (teclado[i], -1,0,
			        &attr[i], & texto[i], NULL, &error) ) {
         g_warning ("Failed to set text from markup due to error parsing markup: %s\nThis is the text that caused the error: %s i=%3d",  error->message, teclado[i], i);
       }
     boton[i] = gtk_button_new_with_label (texto[i]);
     gtk_table_attach_defaults (GTK_TABLE(table), boton[i], c, c+1, f, f+1);
     gtk_widget_show (boton[i]);
     }
   /* cada boton con su senyal */
   for (i=0; i<nc; i++) {
     gtk_signal_connect (GTK_OBJECT (boton[i]), "clicked",
		         GTK_SIGNAL_FUNC (callbackBVteclado), teclado[i]);
     }
   /* mostrar */
   gtk_widget_show (table);
   gtk_widget_show (windowKb);
}

void preparaYpresentaVent1 ()
{
/*
  preparaYpresentaVen2 (tecladoMisc,  4, "miscel");
  preparaYpresentaVen2 (tecladoPnt , 11, "puntuacion");

*/
/*
*/
  if (l_opcion) {
    switch (l_valor_idiom) {
      case idiom_To1:
        preparaYpresentaVen2 (tecladoFra , 26, "frances");
        preparaYpresentaVen2 (tecladoAlem,  7, "aleman");
        preparaYpresentaVen2 (tecladoIsl,  16, "islandes");
        preparaYpresentaVen2 (tecladoIta,  20, "italiano");
        preparaYpresentaVen2 (tecladoPol , 18, "polaco");
        preparaYpresentaVen2 (tecladoPort,  22, "portugues");
	break ;
      case idiom_epo:
        preparaYpresentaVen2 (tecladoEspe,  12, "esperanto");
	break ;
      case idiom_fra:
        preparaYpresentaVen2 (tecladoFra , 26, "frances");
	break ;
      case idiom_ger:
        preparaYpresentaVen2 (tecladoAlem,  7, "aleman");
	break ;
      case idiom_heb:
        preparaYpresentaVen2 (tecladoHebr,  5, "hebreo");
	break ;
      case idiom_isl:
        preparaYpresentaVen2 (tecladoIsl,  16, "islandes");
	break ;
      case idiom_ita:
        preparaYpresentaVen2 (tecladoIta,  20, "italiano");
	break ;
      case idiom_pol:
        preparaYpresentaVen2 (tecladoPol , 18, "polaco");
	break ;
      case idiom_por:
        preparaYpresentaVen2 (tecladoPort,  22, "portugues");
	break ;
      case idiom_rus:
        preparaYpresentaVen2 (tecladoRus,  67, "ruso");
	break ;
      case idiom_vie:
        preparaYpresentaVen2 (tecladoViet,  134, "vietnamita");
	break ;
      }
    }
  preparaYpresentaVen2 (tecladoEspa,  2, "espanol");
  preparaYpresentaVen2 (tecladoMisc,  4, "miscel");
  preparaYpresentaVen2 (tecladoPnt , 11, "puntuacion");
}
